Module register

Module register 

The definitions of drivers of the TMP117

Structs

Address
The address of the register
Configuration
Configuration register of the tpm117
DeviceID
Indicates the device ID
EEPROM
The eeprom configuration register
HighLimit
The high limit register is a 16-bit, read/write register that stores the high limit for comparison with the temperature result. One LSB equals 7.8125 m°C. The range of the register is ±256 °C. Negative numbers are represented in binary two’s complement format. Following power-up or a general-call reset, the high-limit register is loaded with the stored value from the EEPROM. The factory default reset value is 6000h. Is written in two’s complement.
LowLimit
The low limit register is configured as a 16-bit, read/write register that stores the low limit for comparison with the temperature result. One LSB equals 7.8125 m°C. The range of the register is ±256 °C. Negative numbers are represented in binary two’s complement format. The data format is the same as the temperature register. Following power-up or reset, the low-limit register is loaded with the stored value from the EEPROM. The factory default reset value is 8000h.Is written in two’s complement.
Temperature
Temperature register. The value is in 1/7.8125 m°C. Following a reset, the temperature register reads –256 °C until the first conversion, including averaging, is complete. Is in two complements
TemperatureOffset
This 16-bit register is to be used as a user-defined temperature offset register during system calibration. The offset will be added to the temperature result after linearization. It has a same resolution of 7.8125 m°C and same range of ±256 °C as the temperature result register. The data format is the same as the temperature register. If the added result is out of boundary, then the temperature result will show as the maximum or minimum value. Is written in two’s complement.
UEEPROM1
The EEPROM1 register is a 16-bit register that be used as a scratch pad by the customer to store general- purpose data. This register has a corresponding EEPROM location. Writes to this address when the EEPROM is locked write data into the register and not to the EEPROM. Writes to this register when the EEPROM is unlocked causes the corresponding EEPROM location to be programmed. To support NIST tracebility, do not delete or reprogram the UEEPROM1 register
UEEPROM2
Same function as register UEEPROM1 minus the ID for NSIT tracability
UEEPROM3
Same function as register UEEPROM1 minus the ID for NSIT tracability

Enums

AlertPinSelect
Represent the dataready or alert pin select
Average
Conversion averaging modes. Determines the number of conversion results that are collected and averaged before updating the temperature register. The average is an accumulated average and not a running average.
Conversion
Conversion cycle. It depends on the average selected. The enum represents the values for no average.
ConversionMode
Conversion mode
Polarity
Possible polarities
TriggerMode
Possible mode selection