TemperatureOffset

Struct TemperatureOffset 

pub struct TemperatureOffset { /* private fields */ }
This 16-bit register is to be used as a user-defined temperature offset register during system calibration. The offset will be added to the temperature result after linearization. It has a same resolution of 7.8125 m°C and same range of ±256 °C as the temperature result register. The data format is the same as the temperature register. If the added result is out of boundary, then the temperature result will show as the maximum or minimum value. Is written in two’s complement.

Implementations

Source

impl TemperatureOffset

pub fn new(val_0: u16) -> Self

pub fn val_0(&self) -> u16

pub fn set_val_0(&mut self, value: u16)